#
# spec file for package facetimehd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           facetimehd
Version:        0.6.8.2
Release:        2.2
Summary:        Kernel driver for the Apple FacetimeHD webcams
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://github.com/patjak/facetimehd
Source0:        https://github.com/patjak/facetimehd/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        preamble
Patch0:         Remove-use-of-linux-pci-aspm.h-since-it-s-not-in-the.patch
Patch1:         0001-Fix-include-of-prandom.patch
BuildRequires:  %{kernel_module_package_buildreqs}
ExclusiveArch:  x86_64
%kernel_module_package -p %{_sourcedir}/preamble

%description
Reverse engineered Linux driver for the FacetimeHD PCIe webcam

%prep
%setup -q
%if 0%{?sle_version} == 150300
%patch -P 0 -p1
%endif
%if 0%{?sle_version} >= 150300 || 0%{?suse_version} >= 1600
%patch -P 1 -p1
%endif

set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
for flavor in %{flavors_to_build}; do
        rm -rf obj/$flavor
        cp -r source obj/$flavor
        %make_build -C %{kernel_source $flavor} modules M=$PWD/obj/$flavor
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
for flavor in %{flavors_to_build}; do
        make -C %{kernel_source $flavor} modules_install M=$PWD/obj/$flavor
done

%changelog
* Mon Feb  3 2025 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Only build for x86_64
- 0001-Fix-include-of-prandom.patch
  * Fixes a build failure due to changes in kernel
* Wed Jun  5 2024 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 0.6.8.2
  * Adds firmware filename to modinfo
- Add tag for requiring the firmware in the preamble file
* Thu May 16 2024 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 0.6.8.1
  * Fixes build issue
- Removed 0001-v4l2-accommodate-to-struct-filed-rename-of-vb2_buffe.patch
  * No longer needed
* Thu Mar 21 2024 Christophe Marin <christophe@krop.fr>
- Add build fix for recent kernel versions:
  * 0001-v4l2-accommodate-to-struct-filed-rename-of-vb2_buffe.patch
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Feb  5 2024 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 0.6.8
  * Fixes compile issue with newer kernels
* Tue Mar 21 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Exclude architecture s390x because of missing webcam drivers for mainframes
* Fri Jun  3 2022 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Fixed autoload of module
- Fixed build issue with Linux v5.18
* Tue Oct 19 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update the archive to match what is on github
- Update the name of the github project
* Thu Sep  9 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Indentation before %%patch0 failed build so revert that change
* Thu Sep  9 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- spec-cleaner cleanups
* Wed Jun  9 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Fix build for Leap 15.3
* Thu Aug 27 2020 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Added dependency to facetimehd-firmware package
* Mon Aug 24 2020 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Fix so that the package actually builds
* Fri Jun 12 2020 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Initial version 0.5.7
